@@ -27,6 +27,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QGraphicsGridLayout>
 #include <QLabel>
 
+#include <KIcon> 
+
 #include <solid/control/wirelessaccesspoint.h>
 #include <solid/control/wirelessnetworkinterface.h>
 #include <solid/control/networkinterface.h>
@@ -61,6 +63,9 @@ void WirelessInterfaceItem::connectButtonClicked()
 
 void WirelessInterfaceItem::setConnectionInfo()
 {
+    if (!m_iface) {
+        return;
+    }
     InterfaceItem::setConnectionInfo(); // Sets the labels
     switch (m_iface.data()->connectionState()) {
         case Solid::Control::NetworkInterfaceNm09::Unavailable:
